/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.crop.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * Model object representing a crop
 * @author Merijn Zengers
 */
public class CropDefinition extends CropBean implements Serializable {
    
    private List<Variety> varieties;
    private List<Genus> genera;
    public static final String PROP_GENUS = "genera";
    public static final String PROP_VARIETIES = "varieties";
    public static final String USER_INPUT = "user_input";
    
    public CropDefinition(String source){
        varieties = new ArrayList();
        genera = new ArrayList<>();
    }

    public CropDefinition(String name, List<Variety> varieties, List<Genus> genera) {
        setName(name);
        this.varieties = varieties;
        this.genera = genera;
    }
    

    public void setGenera(ArrayList genera) {
        List<Genus> old = this.genera;
        this.genera = genera;
        getPropertyChangeSupport().firePropertyChange(PROP_GENUS, old, genera);
    }

    public void setVarieties(ArrayList varieties) {
        List<Variety> old = this.varieties;
        this.varieties = varieties;
        getPropertyChangeSupport().firePropertyChange(PROP_VARIETIES, old, varieties);
    }
    
    public List<Variety> getVarieties() {
        return varieties;
    }

    
    public void addVariety(Variety race){
        List<Variety> old = new ArrayList<>(this.varieties); 
        this.varieties.add(race);
        getPropertyChangeSupport().firePropertyChange(PROP_VARIETIES, null, race);
        fireUndoableEvent(PROP_VARIETIES, this, old, this.varieties);
    }
            
    public void removeVariety(Variety race){
        List<Variety> old = new ArrayList<>(this.varieties); 
        this.varieties.remove(race);
        getPropertyChangeSupport().firePropertyChange(PROP_VARIETIES, race, null);
        fireUndoableEvent(PROP_VARIETIES, this, old, this.varieties);
    }
    
    public List<Genus> getGenera() {
        return genera;
    }

    public void addGenus(Genus genus) {
        List<Genus> old = new ArrayList<>(this.genera); 
        this.genera.add(genus);
        getPropertyChangeSupport().firePropertyChange(PROP_GENUS, null, genus);
        fireUndoableEvent(PROP_GENUS, this, old, this.genera);
    }
    
    public void removeGenus(Genus genus){
        List<Genus> old = new ArrayList<>(this.genera); 
        this.genera.remove(genus);
        getPropertyChangeSupport().firePropertyChange(PROP_GENUS, genus, null);
        fireUndoableEvent(PROP_GENUS, this, old, this.genera);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        if(!super.equals(obj)){
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        return hash;
    }
    
    
    
}
